aboutsummaryrefslogtreecommitdiff
path: root/common/hooks/pre-pkg
diff options
context:
space:
mode:
Diffstat (limited to 'common/hooks/pre-pkg')
-rw-r--r--common/hooks/pre-pkg/90-set-timestamps.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/common/hooks/pre-pkg/90-set-timestamps.sh b/common/hooks/pre-pkg/90-set-timestamps.sh
index a60a90f1ddf..dcb0b57a489 100644
--- a/common/hooks/pre-pkg/90-set-timestamps.sh
+++ b/common/hooks/pre-pkg/90-set-timestamps.sh
@@ -4,8 +4,8 @@
hook() {
local GIT_CMD date basepkg
- # If XBPS_USE_GIT_COMMIT_DATE is disabled in conf file don't continue.
- if [ -z $XBPS_USE_GIT_COMMIT_DATE ]; then
+ # If XBPS_USE_BUILD_MTIME is enabled in conf file don't continue.
+ if [ -n "$XBPS_USE_BUILD_MTIME" ]; then
return
fi